.ff_optimise_one_lineup: Optimise single lineup
Description
Optimises lineups for one franchise week at a time. Use purrr or loops to do more franchises/weeks/seasons
Usage
.ff_optimise_one_lineup(franchise_scores, lineup_constraints)
Value
a list including the optimal_score and the optimal_lineup.
Arguments
- franchise_scores
a data frame of scores for one week and one franchise
- lineup_constraints
a data frame as created by ffscrapr::ff_starter_positions()