Learn R Programming

ffsimulator (version 1.2.3)

ffs_adp_outcomes_week: Connects ff_scoringhistory to past ADP rankings

Description

The backbone of the ffsimulator resampling process is coming up with a population of weekly outcomes for every inseason weekly rank. This function creates that dataframe by connecting historical FantasyPros.com rankings to nflfastR-based scoring data, as created by ffscrapr::ff_scoringhistory().

Usage

ffs_adp_outcomes_week(scoring_history, pos_filter = c("QB", "RB", "WR", "TE"))

Value

a dataframe with position, rank, probability of games played, and a corresponding nested list per row of all week score outcomes.

Arguments

scoring_history

a scoring history table as created by ffscrapr::ff_scoringhistory()

pos_filter

a character vector: filter the positions returned to these specific positions, default: c("QB","RB","WR","TE)

See Also

fp_rankings_history_week for the included historical rankings

Examples

Run this code
# \donttest{
# cached data
scoring_history <- .ffs_cache("mfl_scoring_history.rds")
ffs_adp_outcomes_week(scoring_history, pos_filter = c("QB","RB","WR","TE"))
# }

Run the code above in your browser using DataLab