Learn R Programming

ffsimulator (version 1.2.3)

ffs_latest_rankings: Download latest rankings from DynastyProcess GitHub

Description

Fetches a copy of the latest FantasyPros redraft positional rankings data from DynastyProcess.com's data repository.

Usage

ffs_latest_rankings(type = c("draft", "week"))

Value

a dataframe with a copy of the latest FP rankings from DynastyProcess's data repository

Arguments

type

one of "draft" or "week" - controls whether to pull preseason or inseason rankings.

Details

If you have any issues with the output of this data, please open an issue in the DynastyProcess data repository.

See Also

https://github.com/dynastyprocess/data

vignette("custom") for example usage

Examples

Run this code
# \donttest{
try({ # try block to prevent CRAN-related issues
ffs_latest_rankings()
})
# }

Run the code above in your browser using DataLab