powered by
Fetches a copy of the latest FantasyPros redraft positional rankings data from DynastyProcess.com's data repository.
ffs_latest_rankings(type = c("draft", "week"))
a dataframe with a copy of the latest FP rankings from DynastyProcess's data repository
one of "draft" or "week" - controls whether to pull preseason or inseason rankings.
If you have any issues with the output of this data, please open an issue in the DynastyProcess data repository.
https://github.com/dynastyprocess/data
vignette("custom") for example usage
vignette("custom")
# \donttest{ try({ # try block to prevent CRAN-related issues ffs_latest_rankings() }) # }
Run the code above in your browser using DataLab